@@ -41,10 +41,6 @@ public:
     void save() override;
     void defaults() override;
 
-#if QT_VERSION_MAJOR < 6
-    void setNeedsSave(bool needs) {emit changed(needs);}
-#endif
-
 public Q_SLOTS:
     void slotFontSize(int);
     void slotMinimumFontSize(int);
