@@ -13,6 +13,7 @@
 #include "konqview.h"
 #include "konqsettings.h"
 #include "konqmainwindowfactory.h"
+#include "urlloader.h"
 
 #include <konqdebug.h>
 
@@ -20,12 +21,12 @@
 #include <KConfigGroup>
 #include <KParts/ReadOnlyPart>
 
+#include <qtwebenginecoreglobal.h>
+
 using namespace KonqInterfaces;
 
-#define CHROME_VERSION "108.0.5359.220"
-
 QString KonqBrowser::konquerorUserAgent() {
-    QString s_konqUserAgent{QStringLiteral("Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) QtWebEngine/%1 Chrome/%2 Safari/537.36 Konqueror (WebEngine)").arg(qVersion()).arg(CHROME_VERSION)};
+    QString s_konqUserAgent{QStringLiteral("Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) QtWebEngine/%1 Chrome/%2 Safari/537.36 Konqueror (WebEngine)").arg(qWebEngineVersion()).arg(qWebEngineChromiumVersion())};
     return s_konqUserAgent;
 }
 
@@ -151,3 +152,14 @@ void KonqBrowser::setSaveDirForWindow(const QString& saveDir, QWidget* window)
         mw->setSaveDir(saveDir);
     }
 }
+
+QString KonqBrowser::partForLocalFile(const QString& path, const QString& mimeType)
+{
+    if (!mimeType.isEmpty()) {
+        QString part = UrlLoader::partForMimetype(mimeType);
+        if (!part.isEmpty()) {
+            return part;
+        }
+    }
+    return UrlLoader::partForLocalFile(path);
+}
