@@ -20,16 +20,12 @@ namespace KIO {
 
 namespace WebEngine {
 
-class WebEnginePartHtmlEmbedder;
-
 /**
  * @brief Class which allows QWebEngine to access URLs provided by KIO
  * 
  * The class assumes that the data can be obtained from KIO using `KIO::storedGet` and
  * passes it to `QWebEngineUrlRequestJob::reply`. The mime type is determined using 
- * `QMimeDatabase::mimeTypeForData`. If the data is HTML or XHTML, on Qt versions before 5.12
- * WebEnginePartHtmlEmbedder is used to embed the contents of local URLs inside the code,
- * so that it can be displayed by QWebEngine without breaking cross-origin rules.
+ * `QMimeDatabase::mimeTypeForData`.
  * 
  * This class provides a virtual function, processSlaveOutput() which allows to further process KIO output before
  * using it as reply. Derived classes can use it to change the data, its mimetype and to set 
@@ -61,37 +57,25 @@ public:
      * @param  req: the request job
      */
     void requestStarted(QWebEngineUrlRequestJob* req) override;
-    
-protected slots:
-    
-    /**
-    * @brief Slot called in response to the WebEnginePartHtmlEmbedder::finished() signal
-    * 
-    * The base class implementation calls setData() with the resulting HTML code, then
-    * emits the ready() signal. You can override this function to do something else with
-    * the HTML code. In this case, most likely you won't want to call the base class version
-    * but just call setData() and emit the ready() when you're done processing the HTML code
-    * 
-    * @param html: the HTML code produced by the embedder 
-    */
-    virtual void embedderFinished(const QString &html);
-    
+
 protected:
+
+    using MaybeJobError = std::optional<QWebEngineUrlRequestJob::Error>;
     
     /**
     * @brief Creates and returns the html embedder object
-    * 
-    * This is the object used to replace local URLs with their content as `data` URLs. 
+    *
+    * This is the object used to replace local URLs with their content as `data` URLs.
     *
     * The embedder is only created on the first use of this function. When this happens, its
     * WebEnginePartHtmlEmbedder::finished() signal is connected to the embedderFinished(). If you
     * don't want this, either disconnect the signal or reimplement embedderFinished() so that it
     * does nothing, then connect WebEnginePartHtmlEmbedder::finished() with the appropriate slot
     * yourself
-    * 
+    *
     * @return the html embedder
     */
-    
+
     /**
      * @brief The request object
      * 
@@ -102,32 +86,38 @@ protected:
     /**
      * @brief The error code to pass to `QWebEngineUrlRequestJob::fail`
      * 
-     * In the base class implementation, this can be either `QWebEngineUrlRequestJob::NoError` or
-     * `QWebEngineUrlRequestJob::RequestFailed`.
+     * In the base class implementation, this can be either `QWebEngineUrlRequestJob::RequestFailed`
+     * or std::nullopt if the request succeeded
      * 
      * @return the error code to pass to `QWebEngineUrlRequestJob::fail`
      */
-    inline QWebEngineUrlRequestJob::Error error() const {return m_error;}
+    inline MaybeJobError error() const {return m_error;}
     
     /**
      * @brief Sets the error code passed to `QWebEngineUrlRequestJob::fail`
      * 
-     * Changes the error code. This function can be called by derived class in their
-     * implementation of processSlaveOutput(). It should always be set to `QWebEngineUrlRequestJob::NoError`
-     * if `QWebEngineUrlRequestJob::reply` should be called.
+     * Passing `std::nullopt` here will mark the request as successful.
+     *
+     * This function can be called by derived class in their implementation of processSlaveOutput().
+     *
+     * Note that there may be situations where the slave produces an error but the URL request should
+     * be considered successful. This happens if, despite the failure, there's something to show the user
+     * (for example, when the slave produced an error message which is more informative than the generic
+     * message QtWebEngine would have produced). In this case, pass `std::nullopt` here.
      * 
      * @see isSuccessful()
      * 
-     * @param error: the new error code
+     * @param error: the new error code. Pass `std::nullopt` to clear any previously set error code
+     * and treat the request as successful
      */
-    inline void setError(QWebEngineUrlRequestJob::Error error) {m_error = error;}
+    inline void setError(MaybeJobError error) {m_error = error;}
     
     /**
      * @brief Whether an error has occurred or not
      * 
-     * @return `true` if error() is `QWebEngineUrlRequestJob::NoError` and false otherwise
+     * @return `true` if error() is `std::nullopt` and false otherwise
      */
-    inline bool isSuccessful() const {return m_error == QWebEngineUrlRequestJob::NoError;}
+    inline bool isSuccessful() const {return !m_error.has_value();}
     
     /**
      * @brief The error message
@@ -273,10 +263,12 @@ private:
     
     /**
      * @brief The error code to use for `QWebEngineUrlRequestJob::fail` for the current request
+     *
+     * A value of `std::nullopt` means no error occurred.
      * 
      * This is valid only after the call to kioJobFinished()
      */
-    QWebEngineUrlRequestJob::Error m_error;
+    MaybeJobError m_error;
     
     /**
      * @brief The error message produced by KIO for the current request
