@@ -152,6 +152,16 @@ WebEnginePart::~WebEnginePart()
 {
 }
 
+QWebEngineProfile * WebEnginePart::defaultProfile()
+{
+    return KonqWebEnginePart::Profile::defaultProfile();
+}
+
+QWebEngineProfile * WebEnginePart::profile() const
+{
+    return defaultProfile();
+}
+
 void WebEnginePart::setPage(WebEnginePage* newPage)
 {
     WebEnginePage *oldPage = page();
@@ -311,6 +321,7 @@ void WebEnginePart::setWallet(WebEngineWallet* wallet)
         disconnect(m_wallet, &WebEngineWallet::walletOpened, this, &WebEnginePart::updateWalletActions);
     }
     m_wallet = wallet;
+    updateWalletActions();
     if (m_wallet) {
         connect(m_wallet, &WebEngineWallet::saveFormDataRequested,
                 this, &WebEnginePart::slotSaveFormDataRequested);
@@ -799,7 +810,7 @@ void WebEnginePart::slotShowWalletMenu()
 
 void WebEnginePart::slotLaunchWalletManager()
 {
-    const KService::Ptr kwalletManager = KService::serviceByDesktopName(QStringLiteral("org.kde.kwalletmanager5"));
+    const KService::Ptr kwalletManager = KService::serviceByDesktopName(QStringLiteral("org.kde.kwalletmanager"));
     auto job = new KIO::ApplicationLauncherJob(kwalletManager);
     job->start();
 }
@@ -1005,32 +1016,32 @@ void WebEnginePart::slotWalletSavedForms(const QUrl& url, bool success)
 
 void WebEnginePart::createWalletActions()
 {
-    QAction *a = new QAction(i18nc("Fill the Forms with Data from KWallet", "&Fill forms now"), this);
+    QAction *a = new QAction(i18nc("Fill the Forms with Data from KWallet", "&Fill In Credentials"), this);
     actionCollection()->addAction("walletFillFormsNow", a);
     actionCollection()->setDefaultShortcut(a, QKeySequence("Ctrl+Shift+V"));
     connect(a, &QAction::triggered, this, [this]{if(page() && m_wallet){m_wallet->detectAndFillPageForms(page());}});
 
-    a = new QAction(i18nc("Scans again the page to detect forms to fill", "Look Again for Forms"), this);
+    a = new QAction(i18nc("Scans again the page to detect forms to fill", "&Search Page for Credential Requests"), this);
     actionCollection()->addAction("walletRescan", a);
     connect(a, &QAction::triggered, this, [this]{if(page() && m_wallet){m_wallet->detectAndFillPageForms(page());}});
 
-    a = new QAction(i18n("&Memorize Passwords in This Page Now"), this);
+    a = new QAction(i18nc("Store in KWallet the current content of the fields", "&Store Credentials Now"), this);
     actionCollection()->addAction("walletCacheFormsNow", a);
     connect(a, &QAction::triggered, this, [this]{if (page() && m_wallet){m_wallet->savePageDataNow(page());}});
 
-    a = new QAction(i18n("&Customize Fields to Memorize for This Page..."), this);
+    a = new QAction(i18nc("Shows a dialog where the use can choose which fields to store", "&Customize Credentials Settings for Page..."), this);
     actionCollection()->addAction("walletCustomizeFields", a);
     connect(a, &QAction::triggered, this, [this](){if (m_wallet){m_wallet->customizeFieldsToCache(page(), view());}});
 
-    a = new QAction(i18n("Remove Customized Memorization Settings for This Page"), this);
+    a = new QAction(i18n("Reset Custom Credential Settings for Page"), this);
     actionCollection()->addAction("walletRemoveCustomization", a);
     connect(a, &QAction::triggered, this, [this](){m_wallet->removeCustomizationForPage(url());});
 
-    KToggleAction *ta = new KToggleAction (i18n("&Allow Password Caching for This Site"), this);
+    KToggleAction *ta = new KToggleAction (i18n("&Allow Credential Caching for This Page"), this);
     actionCollection()->addAction("walletDisablePasswordCaching", ta);
     connect(ta, &QAction::triggered, this, &WebEnginePart::togglePasswordStorableState);
 
-    a = new QAction(i18n("Remove All Memorized Passwords for This Site"), this);
+    a = new QAction(i18n("Remove All Stored Passwords for This Site"), this);
     actionCollection()->addAction("walletRemoveCachedData", a);
     connect(a, &QAction::triggered, this, &WebEnginePart::slotRemoveCachedPasswords);
 
@@ -1050,7 +1061,7 @@ void WebEnginePart::updateWalletActions()
     bool enableCaching = m_webView && !WebEngineSettings::self()->isNonPasswordStorableSite(m_webView->url().host());
     bool hasCustomForms = m_wallet && m_wallet->hasCustomizedCacheableForms(url());
     actionCollection()->action("walletFillFormsNow")->setEnabled(enableCaching && m_wallet && m_walletData.hasCachedData);
-    actionCollection()->action("walletRescan")->setEnabled(enableCaching && m_wallet && m_walletData.hasCachedData);
+    actionCollection()->action("walletRescan")->setEnabled(enableCaching && m_wallet && !Utils::isKonqUrl(url()));
     actionCollection()->action("walletCacheFormsNow")->setEnabled(enableCaching && m_wallet && (m_walletData.hasAutoFillableForms || hasCustomForms));
     actionCollection()->action("walletCustomizeFields")->setEnabled(enableCaching && m_walletData.hasForms);
     actionCollection()->action("walletRemoveCustomization")->setEnabled(hasCustomForms);
