@@ -18,8 +18,7 @@
 #include <KJob>
 #include <QPointer>
 
-#include "browseropenorsavequestion.h"
-#include "interfaces/downloaderextension.h"
+#include "interfaces/downloadjob.h"
 
 class WebEnginePage;
 class QWebEngineProfile;
@@ -37,18 +36,21 @@ public:
     /**
      * @brief Enum which describes what the user wants to do with a URL once it has been downloaded
      *
-     * Currently there are three possibilities:
+     * Currently there are the following possibilities:
      * - the user wants to open the URL in the application embedding the part (for example, when
-     *  clicking on a link). This is the default download objective
+     *  clicking on a link). This is the default download objective)
      * - the user wants to save locally the file represented by the URL (for example, when using
-     *  the "save link as..." context menu entry
+     *  the "save link as..." context menu entry)
      * - the user wants to save the currently displayed page locally (for example, when using the "Save as"
-     *  menu entry
+     *  menu entry)
+     * - we need to ask the user what to do (for example because of "attachment" Content-Disposition header:
+     *  in this case, asking the user is more flexible than just forcing saving)
      */
     enum class DownloadObjective {
         OpenInApplication, //!< A URL is to be downloaded to be opened in the application
-        SaveAs, //!< The current page is to saved locally
-        SaveOnly //!< A URL is to be saved locally
+        SavePageAs, //!< The current page is to saved locally
+        SaveUrl, //!< A URL is to be saved locally
+        AskUser //!< Ask the user what to do
     };
 
     /**
@@ -104,6 +106,15 @@ private:
 
     static QTemporaryDir& tempDownloadDir();
 
+    /**
+     * @brief Asks Konqueror to download the given URL using KonqInterfaces::Browser::openUrl()
+     *
+     * This should only be called when there's no part associated with a download request
+     * @param url the URL to download
+     * @param mimeType the mimetype of the URL
+     */
+    bool downloadWithoutPart(const QUrl &url, const QString &mimeType);
+
 public Q_SLOTS:
     void addPage(WebEnginePage *page);
     void removePage(QObject *page);
@@ -125,7 +136,7 @@ private:
     QMultiHash<QUrl, DownloadObjectiveWithPage> m_downloadObjectives;
 };
 
-class WebEngineDownloadJob : public KonqInterfaces::DownloaderJob
+class WebEngineDownloadJob : public KonqInterfaces::DownloadJob
 {
     Q_OBJECT
 
@@ -146,6 +157,27 @@ public:
 
     QWebEngineDownloadRequest* item() const;
 
+    Intent intent() const override;
+    void setIntent(Intent intent) override;
+
+    /**
+     * @brief Whether this job has been created while handling the "Save As..." menu entry
+     *
+     * This is used by WebEnginePart::displayActOnDownloadedFileBar. When the user chooses
+     * the "Save As..." menu entry, the newly saved file is always displayed in the current
+     * part, if possible, which means in this case we don't want to also display the action bar
+     * @return `true` if the job has been created in response to the "Save As..." menu entry and
+     * `false` otherwise.
+     */
+    bool calledForSaveAs() const;
+
+    /**
+     * @brief Sets whether this job has been created while handling the "Save As..." menu entry
+     * @param saveAs `true` if the job has been created while handling the "Save As..." menu entry
+     * and `false` (the default) otherwise
+     */
+    void setCalledForSaveAs(bool saveAs);
+
 protected:
     bool doKill() override;
     bool doResume() override;
@@ -159,7 +191,9 @@ private slots:
     void emitDownloadResult(KJob *job);
 
 private:
-    bool m_started = false; ///<! @brief Whether the job has been started or not
+    bool m_started = false; //!< Whether the job has been started or not
+    Intent m_intent = Unknown; //!< The intent of the download
+    bool m_calledForSaveAs = false; //!< Whether this job has been created while handling the "Save As..." menu entry
     QPointer<QWebEngineDownloadRequest> m_downloadItem;
     QDateTime m_startTime;
 };
